PublicKey

Struct PublicKey 

pub struct PublicKey(pub VerifyingKey);
This is a public key, which identifies an actor (usually a person) and is shared.

Tuple Fields

0: VerifyingKey

Implementations

Source

impl PublicKey

pub fn as_hex_string(&self) -> String

Render into a hexadecimal string

Consider converting .into() a PublicKeyHex which is a wrapped type rather than a naked String

pub fn try_from_hex_string(v: &str) -> Result<PublicKey, Error>

Create from a hexadecimal string

pub fn try_as_bech32_string(&self) -> Result<String, Error>

Export as a bech32 encoded string

pub fn try_from_bech32_string(s: &str) -> Result<PublicKey, Error>

Import from a bech32 encoded string

pub fn from_bytes(bytes: &[u8]) -> Result<PublicKey, Error>

Import from raw bytes

pub fn as_bytes(&self) -> Vec<u8>

Export as raw bytes

pub fn verify(&self, message: &[u8], signature: Signature) -> Result<(), Error>

Verify a signed message

Methods from Deref<Target = VerifyingKey>

pub fn as_affine(&self) -> &AffinePoint

Borrow the inner AffinePoint this type wraps.

pub fn to_bytes(&self) -> GenericArray<u8, <Secp256k1 as Curve>::FieldBytesSize>

Serialize as bytes.

pub fn verify_raw( &self, message: &[u8], signature: &Signature, ) -> Result<(), Error>

Compute Schnorr signature.

⚠️ Warning

This is a low-level interface intended only for unusual use cases involving verifying pre-hashed messages, or “raw” messages where the message is not hashed at all prior to being used to generate the Schnorr signature.

The preferred interfaces are the DigestVerifier or PrehashVerifier traits.